/* CORTIME.rex:
    $Id: CORTIME.rex 63 2023-07-07 12:25:51Z jeffr $
    Input:  Time, AM/PM, list of time correction values, time correction column label 
    Output: Corrected time
*/
CORTIME:
parse arg time ampm adj col

/* Get time corrections */
parse value adj with col_a ',' col_b ',' col_c ',' col_d ',' col_e

/* Time correction */
select
    when col = 'a' then
        cor = col_a
    when col = 'b' then
        cor = col_b
    when col = 'c' then
        cor = col_c
    when col = 'd' then
        cor = col_d
    when col = 'e' then
        cor = col_e
    otherwise
        say 'CORTIME.rex error: invalid time correction column.'
        cor = col_a
end

/* Split time into separate hour and minute values */
parse value time with hour ':' minute ':'

/* Compute corrected time */
minute_uncor = minute
minute = minute + cor

if minute >= 60 then do
    hour = hour + 1

    /* Account for case when hour will advance by two hours */
    if minute_uncor = 59 & cor > 60 then do
        hour = hour + 1
        minute = minute - 60
    end

    /* Switch hour to 1 as necessary */
    if hour = 13 then 
        hour = 1

    minute = minute - 60

    /* Switch to AM or PM as necessary */
    if hour = 12 & ampm = 'AM' then
        ampm = 'PM'
    else if hour = 12 & ampm = 'PM' then
        ampm = 'AM'
end

/* Add leading zero to single digit minutes */
if minute < 10 then 
    minute = '0'minute

time = hour':'minute' 'ampm
return time 