/* srss.rex:
    $Id: srss.rex 71 2023-09-05 12:32:09Z jeffr $
    Input:  Sunrise and sunset values from The Old Farmer's Almanac, Filename containing list of time correction values, today (optional, shows values for current day only)
    Output: Date and corrected sunrise, sunset time(s)
*/
parse arg srss_data time_adjs today

if state(srss_data) == 1 then do
	say 'srss.rex error: data file not found.'
	exit 1
end

/* Get time adjustments */
adj = TIMEADJS(time_adjs)

/* Print a header */
say 'Date, Sunrise, Sunset'

/* Main loop */
do while lines(srss_data) > 0
	day = linein(srss_data)

	/* Skip blank lines */
	if day == '' then iterate

	parse value day with date ',' sr ',' sr_col ',' ss ',' ss_col

	sunrise = CORTIME(sr 'AM' adj sr_col)
	sunset = CORTIME(ss 'PM' adj ss_col)

	if today \= 'today' then
		say date', 'sunrise', 'sunset
	else 
		do
			parse value DATE(I) with year '-' month '-' day
			cur = month'/'day'/'year
			if date == cur then
				say date', 'sunrise', 'sunset
	end
end
/* End main loop */
exit 0
